var repControllers = angular.module('repControllers', []);

// reports controller
repControllers.controller('HomePageCtrl', ['$scope', 'reportService', function ($scope, reportService) {
    var viewer;

    // controller's variables
    $scope.resultMessage = "";   // result / info message
    $scope.errorMessage = "";   // error message

    // define public methods
    $scope.getReport = getReport;

    // create HTML viewer
    createViewer();

    // --------------
    // functions definitions
    // --------------

    // initialise & create HTML viewer
    function createViewer() {
        var options = new Stimulsoft.Viewer.StiViewerOptions();

        // modify appearance
        options.height = "100%";
        options.appearance.scrollbarsMode = true;
        options.appearance.backgroundColor = Stimulsoft.System.Drawing.Color.darkGray;

        // customise toolbar options
        options.toolbar.showDesignButton = false;
        options.toolbar.showAboutButton = false;
        options.toolbar.backgroundColor = Stimulsoft.System.Drawing.Color.dimGray;

        // customise exports options
        options.exports.showExportToPdf = true;
        options.exports.ShowExportToWord2007 = true;

        // Create an instance of the viewer
        viewer = new Stimulsoft.Viewer.StiViewer(options, "StiViewer", false);

        // Add the design button event
        /* viewer.onReportDesign = function (e) {
         this.visible = false;
         if (designer == null) createDesigner();
         designer.visible = true;
         designer.report = e.report;
         };*/

        viewer.renderHtml("viewerContainer");
    }

    // create & open the selected report
    function getReport() {
        var report;

        try {

            // reset variables
            $scope.resultMessage = "";   // result / info message
            $scope.errorMessage = "";   // error message

            // Forcibly show process indicator
            viewer.showProcessIndicator();

            // call node service to create and return the report file
            reportService.createReport({}, {}, function (response) {

                if (response && response.hasOwnProperty('statusCode')) {
                    if (response.statusCode == "200") {
                        $scope.resultMessage = response.message;
                        // Timeout need for immediate display loading report indicator
                        setTimeout(function () {
                            // Create a new report instance
                            report = new Stimulsoft.Report.StiReport();
                            // Load reports from JSON object
                            report.load(response.reportData);
                            // Assign the report to the viewer
                            viewer.report = report;
                        }, 50);
                    }
                    else {
                        $scope.errorMessage = "[ERROR] " + response.statusCode + ": " + response.message;
                    }
                } else {
                    // request failed
                    $scope.errorMessage = "Report could not be created " + response.toString();
                }
            });
        }
        catch (e) {
            $scope.errorMessage = e;
        }
    }  // End of 'createRport()' function

}]);
