var express = require('express'),
    bodyParser = require('body-parser'), 	// pull information from HTML POST (express4)
    app = express(),
    fs = require('fs'),
    Stimulsoft = require('stimulsoft-reports-js').Stimulsoft,
    stripBom = require('strip-bom'),
    opentype = require('opentype.js');

app.use(bodyParser.urlencoded({'extended': 'true'})); 			// parse application/x-www-form-urlencoded
app.use(bodyParser.json()); 									// parse application/json
app.use(bodyParser.json({type: 'application/vnd.api+json'})); // parse application/vnd.api+json as json
app.use(express.static(__dirname + '/app'));

// test reports
app.post('/createReport', function (req, res) {
    var report,
        reportTemplate,
        demoData,
        renderedReport;

    // 1. create report object
    report = new Stimulsoft.Report.StiReport();
    console.log('report created');

    // 2. load template
    reportTemplate = fs.readFileSync('./reportTemplates/Images.mrt', "utf8");
    report.load(reportTemplate);
    console.log('report loaded');
    console.log('pages: ' + report.pages.count);

    // 3. Loading demo data
    demoData = stripBom(fs.readFileSync('./reportTemplates/data/Demo.json', "utf8"));
    report.dictionary.databases.clear();
    report.regData("Demo", "Demo", demoData);
    console.log("Demo data loaded into the report. Tables count: ", report.dataStore.count);

    // 4. render the report
    report.renderAsync(function () {
        console.log('report rendered. pages: ' + report.renderedPages.count);

        renderedReport = report.saveDocumentToJsonString();
        //fs.writeFileSync('./reportTemplates/Images.mdz', renderedReport);
        res.send({statusCode: 200, message: "Report Created", reportData: renderedReport});
    });

});

app.get('*', function (req, res) {
    console.log("invalid request. Redirecting to " + req.originalUrl);
    res.redirect('/#' + req.originalUrl);
});

// handle errors
app.use(function (err, req, res, next) {
    console.error(err.stack);
    res.send({statusCode: 500, message: err.message});
});

app.listen(88);
console.log('App listening on port 88');